const path = require('path');
const {CleanWebpackPlugin} = require('clean-webpack-plugin');
const CssMinimizerPlugin = require('css-minimizer-webpack-plugin');
const {WebpackManifestPlugin} = require('webpack-manifest-plugin');
const RemoveEmptyScriptsPlugin = require('webpack-remove-empty-scripts');
const TerserPlugin = require('terser-webpack-plugin');

module.exports = (env) => {

    // noinspection JSValidateTypes,JSUnresolvedVariable
    return {
        entry: {
            // 'hello-elementor': path.resolve(__dirname, 'assets/scss/hello-elementor.scss'),
            'inti-widgets': path.resolve(__dirname, 'assets/widget/index'),
            'inti-widget-countdown': path.resolve(__dirname, 'assets/widget/countdown/index'),
        },

        output: {
            filename: '[name].js',
            path: path.resolve(__dirname, 'public/dist'),
            publicPath: '/dist/',
        },

        mode: env.production ? 'production' : 'development',
        optimization: {
            minimize: env.production,
            minimizer: [new TerserPlugin({
                extractComments: false,
                terserOptions: {
                    format: {
                        comments: false,
                    }
                }
            })],
        },

        plugins: [
            env.production ? new CleanWebpackPlugin() : null,
            new RemoveEmptyScriptsPlugin(),
            new WebpackManifestPlugin(),
            new CssMinimizerPlugin({
                minimizerOptions: {
                    preset: ['default', {
                        discardComments: { removeAll: true },
                    }],
                }
            }),
        ].filter(el => el !== null),

        module: {
            rules: [{
                test: /\.tsx?$/,
                use: 'ts-loader',
                exclude: /node_modules/,
            }, {
                test: /\.scss$/,
                use: [
                    env.production ? '' : 'style-loader',
                    'css-loader',
                    'sass-loader',
                ].filter(el => el.length > 0),
            }],
        },

        externals: {
            'jquery': 'jQuery',
            'elementorFrontend': 'elementorFrontend',
            'elementorModules': 'elementorModules',
        },

        resolve: {
            extensions: ['.tsx', '.ts', '.js'],
            alias: {
                'hello-elementor': path.resolve(__dirname, 'public/themes/hello-elementor'),
            }
        },
    }
};
